veva

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2018 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func File

func File(f string) error

File normalizes and validates a string filename by checking the writability of the containing directory.

func Port

func Port(p string) (string, error)

Port normalizes and validates a string port number with preceding colon.

func TouchFile

func TouchFile(name string) error

TouchFile ...

Types

This section is empty.

Jump to